==> charmcord-0.19.20.tar.gz: charmcord-0.19.20/CharmCord/all_functions.py <==
all_Funcs = [
    "$If",
    "$ElIf",
    "$authorID",
    "$botID",
    "$botName",
    "$botGuilds",
    "$botAvatar",
    "$botMention",
    "$channelCategoryID",
    "$channelCategoryName",
    "$channelChangedRoles",
    "$channelCreated",
    "$channelDelay",
    "$channelID",
    "$channelMention",
    "$channelName",
    "$channelNsfw",
    "$channelPosition",
    "$channelType",
    "$channelURL",
    "$console",
    "$count",
    "$deletedChannel",
    "$editMessage",
    "$deleteMessage",
    "$get",
    "$getVar",
    "$getUserVar",
    "$guildID",
    "$guildName",
    "$guildTextChannels",
    "$let",
    "$mentions",
    "$messageAuthor",
    "$messageContent",
    "$oldChannel",
    "$onlyIf",
    "$ping",
    "$pyEval",
    "$sendMessage",
    "$sendEmbed",
    "$setServerVar",
    "$setUserVar",
    "$setVar",
    "$slashSend",
    "$sum",
    "$userMention",
    "$userName",
    "$wait",
    '$waitMessage',
    "$waitReaction",
    "$memberJoined",
    "$hasPerm",
    "$message",
    "$charmAI",
    "$purge",
    "$messageID",
    "$userID",
    "$defer"
]

date_funcs = ["$channelCreated"]

ifse = ["$If", "$ElIf"]

no_arg_Funcs = ["$botName",
                "$botID",
                "$authorID",
                "$channelID",
                "$guildID",
                "$ping",
                "$botGuilds",
                "$botAvatar",
                "$botMention",
                "$memberJoined",
                "$messageID",
                "$message",
                "$defer"]

newline_char = "*n*"

==> charmcord-1.1.1.tar.gz: charmcord-1.1.1/CharmCord/all_functions.py <==
all_Funcs = [
    "$If",
    "$ElIf",
    "$addButton",
    "$addDropdown",
    "$dropdownOption",
    "$interactionReply",
    "$selectedDropdown",
    "$buttonSend",
    "$authorID",
    "$authorName",
    "$botAvatar",
    "$botGuilds",
    "$botID",
    "$botMention",
    "$botName",
    "$channelCategoryID",
    "$channelCategoryName",
    "$channelChangedRoles",
    "$channelCreated",
    "$channelDelay",
    "$channelID",
    "$channelMention",
    "$channelName",
    "$channelNsfw",
    "$channelPosition",
    "$channelType",
    "$channelURL",
    "$charmAI",
    "$console",
    "$contains",
    "$count",
    "$defer",
    "$deleteMessage",
    "$deletedChannel",
    "$divide",
    "$editMessage",
    "$get",
    "$getJson",
    "$getVar",
    "$guildID",
    "$guildName",
    "$guildTextChannels",
    "$hasPerm",
    "$let",
    "$lower",
    "$memberJoined",
    "$mentions",
    "$message",
    "$messageAuthor",
    "$messageContent",
    "$messageID",
    "$newChannel",
    "$multi",
    "$oldChannel",
    "$onlyIf",
    "$ping",
    "$pyEval",
    "$purge",
    "$random",
    "$reactionAdded",
    "$reactionRemoved",
    "$sendMessage",
    "$sendDM",
    "$sendEmbed",
    "$setServerVar",
    "$setUserVar",
    "$setVar",
    "$slashSend",
    "$sub",
    "$sum",
    "$userMention",
    "$userName",
    "$userID",
    "$wait",
    "$waitMessage",
    "$waitReaction"
]

date_funcs = ["$channelCreated"]

ifse = ["$If", "$ElIf"]

no_arg_Funcs = ["$botName",
                "$botID",
                "$authorID",
                "$authorName",
                "$channelID",
                "$guildID",
                "$ping",
                "$botGuilds",
                "$botAvatar",
                "$botMention",
                "$messageID",
                "$message",
                "$defer"]

newline_char = "*n*"
